==> tomee-project-8.0.14-source-release.zip: tomee-project-8.0.14/server/openejb-http/src/main/java/org/apache/openejb/server/httpd/ServletListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
    * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.server.httpd;

import javax.servlet.Servlet;

public class ServletListener implements HttpListener {
    private final Servlet delegate;
    private final String context;

    public ServletListener(final Servlet instance, final String contextRoot) {
        delegate = instance;
        context = contextRoot;
    }

    @Override
    public void onMessage(final HttpRequest request, final HttpResponse response) throws Exception {
        if (request instanceof HttpRequestImpl) {
            final HttpRequestImpl req = (HttpRequestImpl) request;
            req.initPathFromContext((!context.startsWith("/") ? "/" : "") + context);
        }
        delegate.service(request, response);
    }

    public Servlet getDelegate() {
        return delegate;
    }
}

==> tomee-project-10.1.3-source-release.zip: tomee-project-10.1.3/server/openejb-http/src/main/java/org/apache/openejb/server/httpd/ServletListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
    * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.openejb.server.httpd;

import jakarta.servlet.Servlet;

public class ServletListener implements HttpListener {
    private final Servlet delegate;
    private final String context;

    public ServletListener(final Servlet instance, final String contextRoot) {
        delegate = instance;
        context = contextRoot;
    }

    @Override
    public void onMessage(final HttpRequest request, final HttpResponse response) throws Exception {
        if (request instanceof HttpRequestImpl) {
            final HttpRequestImpl req = (HttpRequestImpl) request;
            req.initPathFromContext((!context.startsWith("/") ? "/" : "") + context);
        }
        delegate.service(request, response);
    }

    public Servlet getDelegate() {
        return delegate;
    }
}
